@@ -12,6 +12,7 @@ import fhirclient.models.range as valRange
 import fhirclient.models.medicationstatement as medication
 from uuid import uuid4
 from .common import *
+import copy
 
 CG_ORDER = ["system", "code"]
 CODE_ORD = ["system", "code", "display"]
@@ -81,7 +82,10 @@ class _Fhir_Helper:
         if(sample_data.GT is not None and
            len(sample_data.GT.split('|')) >= 2 and
            'PS' in sample_data._fields):
-            self.phased_rec_map.setdefault(sample_data.PS, []).append(record)
+            sample_data_ps = sample_data.PS
+            if isinstance(sample_data.PS, list):
+                sample_data_ps = sample_data_ps[0]
+            self.phased_rec_map.setdefault(sample_data_ps, []).append(record)
 
     def initalize_report(self):
         patient_reference = reference.FHIRReference(
@@ -195,7 +199,7 @@ class _Fhir_Helper:
         if annotation_record['phenotype'] is not None:
             associated_phenotype_component = observation.ObservationComponent()
             associated_phenotype_component.code = get_codeable_concept(
-                "http://loinc.org", "81259-4", "Associated phenotype"
+                "http://loinc.org", "81259-4", "predicted phenotype"
             )
             associated_phenotype_component\
                 .valueCodeableConcept = get_codeable_concept(
@@ -222,12 +226,8 @@ class _Fhir_Helper:
         patient_reference = reference.FHIRReference(
             {"reference": "Patient/" + self.patientID})
         alleles = get_allelic_state(record, ratio_ad_dp)
-        dvuid = "dv-" + uuid4().hex[:13]
-        self.fhir_report.update({str(record.POS): dvuid})
-        self.result_ids.append(dvuid)
         observation_dv = observation.Observation()
         observation_dv.resource_type = "Observation"
-        observation_dv.id = dvuid
         observation_dv.meta = meta.Meta(
             {
                 "profile": [
@@ -269,12 +269,15 @@ class _Fhir_Helper:
                     "http://loinc.org", "82155-3",
                     "Genomic Structural Variant copy Number"
                 )
+                copy_number = record.samples[0]["CN"]
+                if isinstance(record.samples[0]["CN"], list):
+                    copy_number = copy_number[0]
                 copy_number_component\
                     .valueQuantity = quantity.Quantity(
                         {
                             "system": "http://unitsofmeasure.org",
                             "code": '1',
-                            "value": record.samples[0]["CN"]
+                            "value": copy_number
                         }
                     )
 
@@ -285,14 +288,13 @@ class _Fhir_Helper:
             # only the INFO.END value.
             if hasattr(record.INFO, 'CIPOS') and hasattr(record.INFO, 'CIEND'):
                 inner_start = record.POS + record.INFO['CIPOS'][1]
-                inner_end = record.INFO['END'] + abs(record.INFO['CIEND'][0])
+                inner_end = record.INFO['END'] - abs(record.INFO['CIEND'][0])
                 outer_start = record.POS - abs(record.INFO['CIPOS'][0])
                 outer_end = record.INFO['END'] + record.INFO['CIEND'][1]
                 outer_start_end_component = observation.ObservationComponent()
                 outer_start_end_component.code = get_codeable_concept(
-                    ("http://hl7.org/fhir/uv/genomics-reporting" +
-                     "/CodeSystem/TbdCodes"),
-                    "outer-start-end", "Variant outer start and end"
+                    "http://loinc.org", "81301-4",
+                    "Variant outer start-end"
                 )
                 outer_start_end_component\
                     .valueRange = valRange.Range(
@@ -311,9 +313,8 @@ class _Fhir_Helper:
 
             inner_start_end_component = observation.ObservationComponent()
             inner_start_end_component.code = get_codeable_concept(
-                ("http://hl7.org/fhir/uv/ge" +
-                 "nomics-reporting/CodeSystem/TbdCodes"), "inner-start-end",
-                "Variant inner start and end"
+                "http://loinc.org", "81302-2",
+                "Variant inner start-end"
             )
             inner_start_end_component\
                 .valueRange = valRange.Range(
@@ -344,9 +345,8 @@ class _Fhir_Helper:
 
             exact_start_end_component = observation.ObservationComponent()
             exact_start_end_component.code = get_codeable_concept(
-                ("http://hl7.org/fhir/uv/genomics-reporting/Code" +
-                 "System/TbdCodes"), "exact-start-end",
-                "Variant exact start and end"
+                "http://loinc.org", "81254-5",
+                "Variant exact start-end"
             )
             exact_start_end_component.valueRange = valRange.Range(
                 {"low": {"value": int(record.POS)}})
@@ -395,18 +395,6 @@ class _Fhir_Helper:
         )
         ref_allele_component.valueString = record.REF
 
-        # The following if condition checks if RECORD.ALT is a
-        # simple character string, for simple variants and structural
-        # variants with INFO.SYTYPE in ['INS'].
-        if(len(record.ALT) == 1 and record.ALT[0] is not None and
-           record.ALT[0].type in ['SNV', 'MNV'] and
-           not (record.is_sv and record.INFO['SVTYPE'] not in ['INS'])):
-            alt_allele_component = observation.ObservationComponent()
-            alt_allele_component.code = get_codeable_concept(
-                "http://loinc.org", "69551-0", "Genomic Alt allele [ID]"
-            )
-            alt_allele_component.valueString = record.ALT[0].sequence
-
         genomic_coord_system_component = observation.ObservationComponent()
         genomic_coord_system_component.code = get_codeable_concept(
             "http://loinc.org", "92822-6", "Genomic coord system"
@@ -452,18 +440,45 @@ class _Fhir_Helper:
                     annotation_record['amino_acid_change']
                 )
 
-        # The following block of code adds a variant component to the list
-        # of components based on the VARIANT_COMPONENTS_ORDER list if it is
-        # declared. The declaration of the variable is ensured using the
-        # locals() dictionary.
-        for variant_component in VARIANT_COMPONENTS_ORDER:
-            if variant_component in locals():
-                observation_dv.component.append(locals()[variant_component])
-
-        self.report.contained.append(observation_dv)
-        self.add_diagnostic_implication(
-            record, ref_seq,
-            observation_dv.id, annotation_record)
+        for alt in record.ALT:
+            if(alt is not None and
+               alt.type in ['SNV', 'MNV'] and
+               not (record.is_sv and record.INFO['SVTYPE'] not in ['INS'])):
+                alt_allele_component = observation.ObservationComponent()
+                alt_allele_component.code = get_codeable_concept(
+                    "http://loinc.org", "69551-0", "Genomic Alt allele [ID]"
+                )
+                alt_allele_component.valueString = f"{alt}"
+                observation_dv.component = []
+                for variant_component in VARIANT_COMPONENTS_ORDER:
+                    if variant_component in locals():
+                        observation_dv.component.append(
+                            locals()[variant_component])
+                dvuid = "dv-" + uuid4().hex[:13]
+                self.fhir_report.update({str(record.POS): dvuid})
+                self.result_ids.append(dvuid)
+                observation_dv.id = dvuid
+                self.report.contained.append(copy.deepcopy(observation_dv))
+                self.add_diagnostic_implication(
+                    record, ref_seq,
+                    observation_dv.id, annotation_record)
+                del alt_allele_component
+            else:
+                if "alt_allele_component" in locals():
+                    del alt_allele_component
+                observation_dv.component = []
+                for variant_component in VARIANT_COMPONENTS_ORDER:
+                    if variant_component in locals():
+                        observation_dv.component.append(
+                            locals()[variant_component])
+                dvuid = "dv-" + uuid4().hex[:13]
+                self.fhir_report.update({str(record.POS): dvuid})
+                self.result_ids.append(dvuid)
+                observation_dv.id = dvuid
+                self.report.contained.append(copy.deepcopy(observation_dv))
+                self.add_diagnostic_implication(
+                    record, ref_seq,
+                    observation_dv.id, annotation_record)
 
     def add_phased_relationship_obv(self):
         patient_reference = reference.FHIRReference(
